@@ -376,6 +376,7 @@ atom residue::create_new_atom(atom_type inType, const std::string &inAtomID, poi
 		{ "auth_comp_id", m_compound_id },
 		{ "auth_seq_id", m_auth_seq_id },
 		{ "occupancy", 1.0f, 2 },
+		{ "B_iso_or_equiv", 20.0f },
 		{ "pdbx_PDB_model_num", m_structure->get_model_nr() },
 	});
 
@@ -450,6 +451,28 @@ atom residue::get_atom_by_atom_id(const std::string &atom_id) const
 	return result;
 }
 
+atom residue::get_atom_by_atom_id(const std::string &atomID, const std::string &altID) const
+{
+	if (altID.empty())
+		return get_atom_by_atom_id(atomID);
+
+	atom result;
+
+	for (auto &a : m_atoms)
+	{
+		if (auto a_alt_id = a.get_label_alt_id(); a.get_label_atom_id() == atomID and (a_alt_id.empty() or a_alt_id == altID))
+		{
+			result = a;
+			break;
+		}
+	}
+
+	if (not result and VERBOSE > 1)
+		std::cerr << "atom with atom_id " << atomID << " and alt_id " << altID << " not found in residue " << m_asym_id << ':' << m_seq_id << '\n';
+
+	return result;
+}
+
 // residue is a single entity if the atoms for the asym with m_asym_id is equal
 // to the number of atoms in this residue...  hope this is correct....
 bool residue::is_entity() const
@@ -562,6 +585,16 @@ bool monomer::is_last_in_chain() const
 	return m_index + 1 == m_polymer->size();
 }
 
+const monomer &monomer::prev() const
+{
+	return m_polymer->at(m_index - 1);
+}
+
+const monomer &monomer::next() const
+{
+	return m_polymer->at(m_index + 1);
+}
+
 bool monomer::has_alpha() const
 {
 	return m_index >= 1 and m_index + 2 < m_polymer->size();
@@ -578,7 +611,7 @@ float monomer::phi() const
 
 	if (m_index > 0)
 	{
-		auto &prev = m_polymer->operator[](m_index - 1);
+		auto &prev = m_polymer->at(m_index - 1);
 		if (prev.m_seq_id + 1 == m_seq_id)
 		{
 			auto a1 = prev.C();
@@ -600,7 +633,7 @@ float monomer::psi() const
 
 	if (m_index + 1 < m_polymer->size())
 	{
-		auto &next = m_polymer->operator[](m_index + 1);
+		auto &next = m_polymer->at(m_index + 1);
 		if (m_seq_id + 1 == next.m_seq_id)
 		{
 			auto a1 = N();
@@ -624,9 +657,9 @@ float monomer::alpha() const
 	{
 		if (m_index >= 1 and m_index + 2 < m_polymer->size())
 		{
-			auto &prev = m_polymer->operator[](m_index - 1);
-			auto &next = m_polymer->operator[](m_index + 1);
-			auto &nextNext = m_polymer->operator[](m_index + 2);
+			auto &prev = m_polymer->at(m_index - 1);
+			auto &next = m_polymer->at(m_index + 1);
+			auto &nextNext = m_polymer->at(m_index + 2);
 
 			result = static_cast<float>(dihedral_angle(prev.CAlpha().get_location(), CAlpha().get_location(), next.CAlpha().get_location(), nextNext.CAlpha().get_location()));
 		}
@@ -648,8 +681,8 @@ float monomer::kappa() const
 	{
 		if (m_index >= 2 and m_index + 2 < m_polymer->size())
 		{
-			auto &prevPrev = m_polymer->operator[](m_index - 2);
-			auto &nextNext = m_polymer->operator[](m_index + 2);
+			auto &prevPrev = m_polymer->at(m_index - 2);
+			auto &nextNext = m_polymer->at(m_index + 2);
 
 			if (prevPrev.m_seq_id + 4 == nextNext.m_seq_id)
 			{
@@ -677,7 +710,7 @@ float monomer::tco() const
 	{
 		if (m_index > 0)
 		{
-			auto &prev = m_polymer->operator[](m_index - 1);
+			auto &prev = m_polymer->at(m_index - 1);
 			if (prev.m_seq_id + 1 == m_seq_id)
 				result = static_cast<float>(cosinus_angle(C().get_location(), O().get_location(), prev.C().get_location(), prev.O().get_location()));
 		}
@@ -699,7 +732,7 @@ float monomer::omega() const
 	try
 	{
 		if (not is_last_in_chain())
-			result = omega(*this, m_polymer->operator[](m_index + 1));
+			result = omega(*this, m_polymer->at(m_index + 1));
 	}
 	catch (const std::exception &ex)
 	{
@@ -795,7 +828,7 @@ bool monomer::is_cis() const
 
 	if (m_index + 1 < m_polymer->size())
 	{
-		auto &next = m_polymer->operator[](m_index + 1);
+		auto &next = m_polymer->at(m_index + 1);
 
 		result = monomer::is_cis(*this, next);
 	}
@@ -2717,9 +2750,12 @@ std::string structure::create_entity_for_branch(branch &branch)
 
 void structure::cleanup_empty_categories()
 {
+
 	using namespace literals;
 
 	auto &atomSite = m_db["atom_site"];
+	auto &pdbxPolySeqScheme = m_db["pdbx_poly_seq_scheme"];
+	auto &entityPolySeq = m_db["entity_poly_seq"];
 
 	// Remove chem_comp's for which there are no atoms at all
 	auto &chem_comp = m_db["chem_comp"];
@@ -2728,8 +2764,12 @@ void structure::cleanup_empty_categories()
 	for (auto chemComp : chem_comp)
 	{
 		std::string compID = chemComp["id"].as<std::string>();
-		if (atomSite.contains("label_comp_id"_key == compID or "auth_comp_id"_key == compID))
+		if (atomSite.contains("label_comp_id"_key == compID or "auth_comp_id"_key == compID) or
+			pdbxPolySeqScheme.contains("mon_id"_key == compID or "auth_mon_id"_key == compID or "pdb_mon_id"_key == compID) or
+			entityPolySeq.contains("mon_id"_key == compID))
+		{
 			continue;
+		}
 
 		obsoleteChemComps.push_back(chemComp);
 	}
@@ -2908,6 +2948,14 @@ static int compare_numbers(std::string_view a, std::string_view b)
 	return result;
 }
 
+int compare_cif_id(const std::string &a, const std::string &b)
+{
+	int d = a.length() - b.length();
+	if (d == 0)
+		d = a.compare(b);
+	return d;
+}
+
 void structure::reorder_atoms()
 {
 	auto &atom_site = m_db["atom_site"];
@@ -2919,7 +2967,7 @@ void structure::reorder_atoms()
 			// First by model number
 			d = a.get<int>("pdbx_PDB_model_num") - b.get<int>("pdbx_PDB_model_num");
 			if (d == 0)
-				d = a.get<std::string>("label_asym_id").compare(b.get<std::string>("label_asym_id"));
+				d = compare_cif_id(a.get<std::string>("label_asym_id"), b.get<std::string>("label_asym_id"));
 			if (d == 0)
 			{
 				auto na = a.get<std::optional<int>>("label_seq_id");
