@@ -90,7 +90,7 @@ TEST_CASE("t1")
 
 	const auto &&[angle, axis] = cif::quaternion_to_angle_axis(q2);
 
-	REQUIRE_THAT(std::fmod(360 + angle, 360), Catch::Matchers::WithinRel(std::fmod(360 - angle0, 360), 0.01));
+	CHECK_THAT(std::fmod(360 + angle, 360), Catch::Matchers::WithinRel(std::fmod(360 - angle0, 360), 0.01));
 
 	for (auto &p : p1)
 		p.rotate(q2);
@@ -116,7 +116,7 @@ TEST_CASE("t2")
 
 	auto &&[angle, axis] = cif::quaternion_to_angle_axis(q);
 
-	REQUIRE_THAT(angle, Catch::Matchers::WithinRel(45.f, 0.01f));
+	CHECK_THAT(angle, Catch::Matchers::WithinRel(45.f, 0.01f));
 }
 
 TEST_CASE("t3")
@@ -140,7 +140,7 @@ TEST_CASE("t3")
 
 	double a = cif::angle(v, p[0], p[1]);
 
-	REQUIRE_THAT(a, Catch::Matchers::WithinRel(45.f, 0.01f));
+	CHECK_THAT(a, Catch::Matchers::WithinRel(45.f, 0.01f));
 }
 
 TEST_CASE("dh_q_0")
@@ -148,16 +148,15 @@ TEST_CASE("dh_q_0")
 	cif::point axis(1, 0, 0);
 
 	cif::point p(1, 1, 0);
-	
-	cif::point t[3] =
-	{
+
+	cif::point t[3] = {
 		{ 0, 1, 0 },
 		{ 0, 0, 0 },
 		{ 1, 0, 0 }
 	};
 
 	auto a = cif::dihedral_angle(t[0], t[1], t[2], p);
-	REQUIRE_THAT(a, Catch::Matchers::WithinRel(0.f, 0.01f));
+	CHECK_THAT(a, Catch::Matchers::WithinRel(0.f, 0.01f));
 
 	auto q = cif::construct_from_angle_axis(90, axis);
 
@@ -180,7 +179,6 @@ TEST_CASE("dh_q_0")
 
 	a = cif::dihedral_angle(t[0], t[1], t[2], p);
 	REQUIRE(std::abs(a - 0.f) < 0.01f);
-
 }
 
 TEST_CASE("dh_q_1")
@@ -222,76 +220,117 @@ TEST_CASE("dh_q_1")
 		pts[3].rotate(q, pts[2]);
 
 		auto dh = cif::dihedral_angle(pts[0], pts[1], pts[2], pts[3]);
-		REQUIRE_THAT(dh, Catch::Matchers::WithinRel(angle, 0.1f));
+		CHECK_THAT(dh, Catch::Matchers::WithinRel(angle, 0.1f));
 	}
 }
 
 // --------------------------------------------------------------------
 
-TEST_CASE("m2q_0, *utf::tolerance(0.001f)")
+// TEST_CASE("m2q_0")
+// {
+// 	for (std::size_t i = 0; i < cif::kSymopNrTableSize; ++i)
+// 	{
+// 		auto d = cif::kSymopNrTable[i].symop().data();
+
+// 		cif::matrix3x3<float> rot;
+// 		float Qxx = rot(0, 0) = d[0];
+// 		float Qxy = rot(0, 1) = d[1];
+// 		float Qxz = rot(0, 2) = d[2];
+// 		float Qyx = rot(1, 0) = d[3];
+// 		float Qyy = rot(1, 1) = d[4];
+// 		float Qyz = rot(1, 2) = d[5];
+// 		float Qzx = rot(2, 0) = d[6];
+// 		float Qzy = rot(2, 1) = d[7];
+// 		float Qzz = rot(2, 2) = d[8];
+
+// 		Eigen::Matrix4f em;
+
+// 		em << Qxx - Qyy - Qzz, Qyx + Qxy, Qzx + Qxz, Qzy - Qyz,
+// 			Qyx + Qxy, Qyy - Qxx - Qzz, Qzy + Qyz, Qxz - Qzx,
+// 			Qzx + Qxz, Qzy + Qyz, Qzz - Qxx - Qyy, Qyx - Qxy,
+// 			Qzy - Qyz, Qxz - Qzx, Qyx - Qxy, Qxx + Qyy + Qzz;
+
+// 		Eigen::EigenSolver<Eigen::Matrix4f> es(em / 3);
+
+// 		auto ev = es.eigenvalues();
+
+// 		std::size_t bestJ = 0;
+// 		float bestEV = -1;
+
+// 		for (std::size_t j = 0; j < 4; ++j)
+// 		{
+// 			if (bestEV < ev[j].real())
+// 			{
+// 				bestEV = ev[j].real();
+// 				bestJ = j;
+// 			}
+// 		}
+
+// 		if (std::abs(bestEV - 1) > 0.01)
+// 			continue; // not a rotation matrix
+
+// 		auto col = es.eigenvectors().col(bestJ);
+
+// 		auto q = normalize(cif::quaternion{
+// 			static_cast<float>(col(3).real()),
+// 			static_cast<float>(col(0).real()),
+// 			static_cast<float>(col(1).real()),
+// 			static_cast<float>(col(2).real()) });
+
+// 		cif::point p1{ 1, 1, 1 };
+// 		cif::point p2 = p1;
+// 		p2.rotate(q);
+
+// 		cif::point p3 = rot * p1;
+
+// 		CHECK_THAT(p2.m_x, Catch::Matchers::WithinRel(p3.m_x, 0.01f));
+// 		CHECK_THAT(p2.m_y, Catch::Matchers::WithinRel(p3.m_y, 0.01f));
+// 		CHECK_THAT(p2.m_z, Catch::Matchers::WithinRel(p3.m_z, 0.01f));
+// 	}
+// }
+
+TEST_CASE("m2q_0a")
 {
 	for (std::size_t i = 0; i < cif::kSymopNrTableSize; ++i)
 	{
 		auto d = cif::kSymopNrTable[i].symop().data();
 
-		cif::matrix3x3<float> rot;
-		float Qxx = rot(0, 0) = d[0];
-		float Qxy = rot(0, 1) = d[1];
-		float Qxz = rot(0, 2) = d[2];
-		float Qyx = rot(1, 0) = d[3];
-		float Qyy = rot(1, 1) = d[4];
-		float Qyz = rot(1, 2) = d[5];
-		float Qzx = rot(2, 0) = d[6];
-		float Qzy = rot(2, 1) = d[7];
-		float Qzz = rot(2, 2) = d[8];
+		Eigen::Matrix3f rot;
+		rot << d[0], d[1], d[2], d[3], d[4], d[5], d[6], d[7], d[8];
 
-		Eigen::Matrix4f em;
+		// check to see if this matrix contains a true rotation
+		if (rot * rot.transpose() != Eigen::Matrix3f::Identity() or rot.determinant() != 1)
+			continue;
 
-		em << Qxx - Qyy - Qzz, Qyx + Qxy, Qzx + Qxz, Qzy - Qyz,
-		      Qyx + Qxy, Qyy - Qxx - Qzz, Qzy + Qyz, Qxz - Qzx,
-			  Qzx + Qxz, Qzy + Qyz, Qzz - Qxx - Qyy, Qyx - Qxy,
-			  Qzy - Qyz, Qxz - Qzx, Qyx - Qxy, Qxx + Qyy + Qzz;
+		Eigen::Quaternionf qe(rot);
 
-		Eigen::EigenSolver<Eigen::Matrix4f> es(em / 3);
+		auto q = normalize(cif::quaternion{ qe.w(), qe.x(), qe.y(), qe.z() });
 
-		auto ev = es.eigenvalues();
-
-		std::size_t bestJ = 0;
-		float bestEV = -1;
-
-		for (std::size_t j = 0; j < 4; ++j)
-		{
-			if (bestEV < ev[j].real())
-			{
-				bestEV = ev[j].real();
-				bestJ = j;
-			}
-		}
-
-		if (std::abs(bestEV - 1) > 0.01)
-			continue; // not a rotation matrix
-
-		auto col = es.eigenvectors().col(bestJ);
-
-		auto q = normalize(cif::quaternion{
-			static_cast<float>(col(3).real()),
-			static_cast<float>(col(0).real()),
-			static_cast<float>(col(1).real()),
-			static_cast<float>(col(2).real()) });
-		
 		cif::point p1{ 1, 1, 1 };
 		cif::point p2 = p1;
 		p2.rotate(q);
 
-		cif::point p3 = rot * p1;
+		cif::matrix3x3<float> rot_c({
+			static_cast<float>(d[0]),
+			static_cast<float>(d[1]),
+			static_cast<float>(d[2]),
+			static_cast<float>(d[3]),
+			static_cast<float>(d[4]),
+			static_cast<float>(d[5]),
+			static_cast<float>(d[6]),
+			static_cast<float>(d[7]),
+			static_cast<float>(d[8])
+		});
 
-		REQUIRE_THAT(p2.m_x, Catch::Matchers::WithinRel(p3.m_x, 0.01f));
-		REQUIRE_THAT(p2.m_y, Catch::Matchers::WithinRel(p3.m_y, 0.01f));
-		REQUIRE_THAT(p2.m_z, Catch::Matchers::WithinRel(p3.m_z, 0.01f));
+		cif::point p3 = rot_c * p1;
+
+		CHECK_THAT(p2.m_x, Catch::Matchers::WithinRel(p3.m_x, 0.01f));
+		CHECK_THAT(p2.m_y, Catch::Matchers::WithinRel(p3.m_y, 0.01f));
+		CHECK_THAT(p2.m_z, Catch::Matchers::WithinRel(p3.m_z, 0.01f));
 	}
 }
 
-// "TEST_CASE(m2q_1, *utf::tolerance(0.001f)")
+// "TEST_CASE(m2q_1")
 // {
 // 	for (std::size_t i = 0; i < cif::kSymopNrTableSize; ++i)
 // 	{
@@ -337,7 +376,7 @@ TEST_CASE("m2q_0, *utf::tolerance(0.001f)")
 // 			static_cast<float>(em(bestJ, 0)),
 // 			static_cast<float>(em(bestJ, 1)),
 // 			static_cast<float>(em(bestJ, 2)) });
-		
+
 // 		cif::point p1{ 1, 1, 1 };
 // 		cif::point p2 = p1;
 // 		p2.rotate(q);
@@ -360,15 +399,15 @@ TEST_CASE("symm_1")
 
 	cif::point f = fractional(p, c);
 
-	REQUIRE_THAT(f.m_x, Catch::Matchers::WithinRel(0.1f, 0.01f));
-	REQUIRE_THAT(f.m_y, Catch::Matchers::WithinRel(0.1f, 0.01f));
-	REQUIRE_THAT(f.m_z, Catch::Matchers::WithinRel(0.1f, 0.01f));
+	CHECK_THAT(f.m_x, Catch::Matchers::WithinRel(0.1f, 0.01f));
+	CHECK_THAT(f.m_y, Catch::Matchers::WithinRel(0.1f, 0.01f));
+	CHECK_THAT(f.m_z, Catch::Matchers::WithinRel(0.1f, 0.01f));
 
 	cif::point o = orthogonal(f, c);
 
-	REQUIRE_THAT(o.m_x, Catch::Matchers::WithinRel(1.f, 0.01f));
-	REQUIRE_THAT(o.m_y, Catch::Matchers::WithinRel(1.f, 0.01f));
-	REQUIRE_THAT(o.m_z, Catch::Matchers::WithinRel(1.f, 0.01f));
+	CHECK_THAT(o.m_x, Catch::Matchers::WithinRel(1.f, 0.01f));
+	CHECK_THAT(o.m_y, Catch::Matchers::WithinRel(1.f, 0.01f));
+	CHECK_THAT(o.m_z, Catch::Matchers::WithinRel(1.f, 0.01f));
 }
 
 TEST_CASE("symm_2")
@@ -390,33 +429,33 @@ TEST_CASE("symm_3")
 	REQUIRE(sg.get_name() == "P 21 21 2");
 }
 
-TEST_CASE("symm_4, *utf::tolerance(0.1f)")
+TEST_CASE("symm_4")
 {
 	using namespace cif::literals;
 
 	// based on 2b8h
 	auto sg = cif::spacegroup(154); // p 32 2 1
 	auto c = cif::cell(107.516, 107.516, 338.487, 90.00, 90.00, 120.00);
-	
-	cif::point a{   -8.688,  79.351, 10.439 }; // O6 NAG A 500
-	cif::point b{  -35.356,  33.693, -3.236 }; // CG2 THR D 400
-	cif::point sb(  -6.916,   79.34,   3.236); // 4_565 copy of b
 
-	REQUIRE_THAT(distance(a, sg(a, c, "1_455"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_a()), 0.01f));
-	REQUIRE_THAT(distance(a, sg(a, c, "1_545"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_b()), 0.01f));
-	REQUIRE_THAT(distance(a, sg(a, c, "1_554"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_c()), 0.01f));
+	cif::point a{ -8.688, 79.351, 10.439 };  // O6 NAG A 500
+	cif::point b{ -35.356, 33.693, -3.236 }; // CG2 THR D 400
+	cif::point sb(-6.916, 79.34, 3.236);     // 4_565 copy of b
+
+	CHECK_THAT(distance(a, sg(a, c, "1_455"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_a()), 0.01f));
+	CHECK_THAT(distance(a, sg(a, c, "1_545"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_b()), 0.01f));
+	CHECK_THAT(distance(a, sg(a, c, "1_554"_symop)), Catch::Matchers::WithinRel(static_cast<float>(c.get_c()), 0.01f));
 
 	auto sb2 = sg(b, c, "4_565"_symop);
-	REQUIRE_THAT(sb.m_x, Catch::Matchers::WithinRel(sb2.m_x, 0.01f));
-	REQUIRE_THAT(sb.m_y, Catch::Matchers::WithinRel(sb2.m_y, 0.01f));
-	REQUIRE_THAT(sb.m_z, Catch::Matchers::WithinRel(sb2.m_z, 0.01f));
+	CHECK_THAT(sb.m_x, Catch::Matchers::WithinRel(sb2.m_x, 0.01f));
+	CHECK_THAT(sb.m_y, Catch::Matchers::WithinRel(sb2.m_y, 0.01f));
+	CHECK_THAT(sb.m_z, Catch::Matchers::WithinRel(sb2.m_z, 0.01f));
 
-	REQUIRE_THAT(distance(a, sb2), Catch::Matchers::WithinRel(7.42f, 0.01f));	
+	CHECK_THAT(distance(a, sb2), Catch::Matchers::WithinRel(7.42f, 0.01f));
 }
 
 // --------------------------------------------------------------------
 
-TEST_CASE("symm_4wvp_1, *utf::tolerance(0.1f)")
+TEST_CASE("symm_4wvp_1")
 {
 	using namespace cif::literals;
 
@@ -427,25 +466,24 @@ TEST_CASE("symm_4wvp_1, *utf::tolerance(0.1f)")
 
 	cif::crystal c(db);
 
-	cif::point p{ -78.722, 98.528,  11.994 };
+	cif::point p{ -78.722, 98.528, 11.994 };
 	auto a = s.get_residue("A", 10, "").get_atom_by_atom_id("O");
 
 	auto sp1 = c.symmetry_copy(a.get_location(), "2_565"_symop);
-	REQUIRE_THAT(sp1.m_x, Catch::Matchers::WithinAbs(p.m_x, 0.5f));
-	REQUIRE_THAT(sp1.m_y, Catch::Matchers::WithinAbs(p.m_y, 0.5f));
-	REQUIRE_THAT(sp1.m_z, Catch::Matchers::WithinAbs(p.m_z, 0.5f));
+	CHECK_THAT(sp1.m_x, Catch::Matchers::WithinAbs(p.m_x, 0.5f));
+	CHECK_THAT(sp1.m_y, Catch::Matchers::WithinAbs(p.m_y, 0.5f));
+	CHECK_THAT(sp1.m_z, Catch::Matchers::WithinAbs(p.m_z, 0.5f));
 
 	const auto &[d, sp2, so] = c.closest_symmetry_copy(p, a.get_location());
 
 	REQUIRE(d < 1);
 
-	REQUIRE_THAT(sp2.m_x, Catch::Matchers::WithinAbs(p.m_x, 0.5f));
-	REQUIRE_THAT(sp2.m_y, Catch::Matchers::WithinAbs(p.m_y, 0.5f));
-	REQUIRE_THAT(sp2.m_z, Catch::Matchers::WithinAbs(p.m_z, 0.5f));
-
+	CHECK_THAT(sp2.m_x, Catch::Matchers::WithinAbs(p.m_x, 0.5f));
+	CHECK_THAT(sp2.m_y, Catch::Matchers::WithinAbs(p.m_y, 0.5f));
+	CHECK_THAT(sp2.m_z, Catch::Matchers::WithinAbs(p.m_z, 0.5f));
 }
 
-TEST_CASE("symm_2bi3_1, *utf::tolerance(0.1f)")
+TEST_CASE("symm_2bi3_1")
 {
 	cif::file f(gTestDir / "2bi3.cif.gz");
 
@@ -455,18 +493,15 @@ TEST_CASE("symm_2bi3_1, *utf::tolerance(0.1f)")
 	cif::crystal c(db);
 
 	auto struct_conn = db["struct_conn"];
-	for (const auto &[
-			asym1, seqid1, authseqid1, atomid1, symm1,
-			asym2, seqid2, authseqid2, atomid2, symm2,
-			dist] : struct_conn.find<
-				std::string,int,std::string,std::string,std::string,
-				std::string,int,std::string,std::string,std::string,
-				float>(
-			cif::key("ptnr1_symmetry") != "1_555" or cif::key("ptnr2_symmetry") != "1_555",
-			"ptnr1_label_asym_id", "ptnr1_label_seq_id", "ptnr1_auth_seq_id", "ptnr1_label_atom_id", "ptnr1_symmetry", 
-			"ptnr2_label_asym_id", "ptnr2_label_seq_id", "ptnr2_auth_seq_id", "ptnr2_label_atom_id", "ptnr2_symmetry", 
-			"pdbx_dist_value"
-		))
+	for (const auto &[asym1, seqid1, authseqid1, atomid1, symm1,
+			 asym2, seqid2, authseqid2, atomid2, symm2,
+			 dist] : struct_conn.find<std::string, int, std::string, std::string, std::string,
+			 std::string, int, std::string, std::string, std::string,
+			 float>(
+			 cif::key("ptnr1_symmetry") != "1_555" or cif::key("ptnr2_symmetry") != "1_555",
+			 "ptnr1_label_asym_id", "ptnr1_label_seq_id", "ptnr1_auth_seq_id", "ptnr1_label_atom_id", "ptnr1_symmetry",
+			 "ptnr2_label_asym_id", "ptnr2_label_seq_id", "ptnr2_auth_seq_id", "ptnr2_label_atom_id", "ptnr2_symmetry",
+			 "pdbx_dist_value"))
 	{
 		auto &r1 = s.get_residue(asym1, seqid1, authseqid1);
 		auto &r2 = s.get_residue(asym2, seqid2, authseqid2);
@@ -477,22 +512,22 @@ TEST_CASE("symm_2bi3_1, *utf::tolerance(0.1f)")
 		auto sa1 = c.symmetry_copy(a1.get_location(), cif::sym_op(symm1));
 		auto sa2 = c.symmetry_copy(a2.get_location(), cif::sym_op(symm2));
 
-		REQUIRE_THAT(cif::distance(sa1, sa2), Catch::Matchers::WithinAbs(dist, 0.5f));
+		CHECK_THAT(cif::distance(sa1, sa2), Catch::Matchers::WithinAbs(dist, 0.5f));
 
 		auto pa1 = a1.get_location();
 
 		const auto &[d, p, so] = c.closest_symmetry_copy(pa1, a2.get_location());
 
-		REQUIRE_THAT(p.m_x, Catch::Matchers::WithinAbs(sa2.m_x, 0.5f));
-		REQUIRE_THAT(p.m_y, Catch::Matchers::WithinAbs(sa2.m_y, 0.5f));
-		REQUIRE_THAT(p.m_z, Catch::Matchers::WithinAbs(sa2.m_z, 0.5f));
+		CHECK_THAT(p.m_x, Catch::Matchers::WithinAbs(sa2.m_x, 0.5f));
+		CHECK_THAT(p.m_y, Catch::Matchers::WithinAbs(sa2.m_y, 0.5f));
+		CHECK_THAT(p.m_z, Catch::Matchers::WithinAbs(sa2.m_z, 0.5f));
 
-		REQUIRE_THAT(d, Catch::Matchers::WithinAbs(dist, 0.5f));
+		CHECK_THAT(d, Catch::Matchers::WithinAbs(dist, 0.5f));
 		REQUIRE(so.string() == symm2);
 	}
 }
 
-TEST_CASE("symm_2bi3_1a, *utf::tolerance(0.1f)")
+TEST_CASE("symm_2bi3_1a")
 {
 	using namespace cif::literals;
 
@@ -504,43 +539,40 @@ TEST_CASE("symm_2bi3_1a, *utf::tolerance(0.1f)")
 	auto struct_conn = db["struct_conn"];
 	auto atom_site = db["atom_site"];
 
-	for (const auto &[
-			asym1, seqid1, authseqid1, atomid1, symm1,
-			asym2, seqid2, authseqid2, atomid2, symm2,
-			dist] : struct_conn.find<
-				std::string,std::optional<int>,std::string,std::string,std::string,
-				std::string,std::optional<int>,std::string,std::string,std::string,
-				float>(
-			cif::key("ptnr1_symmetry") != "1_555" or cif::key("ptnr2_symmetry") != "1_555",
-			"ptnr1_label_asym_id", "ptnr1_label_seq_id", "ptnr1_auth_seq_id", "ptnr1_label_atom_id", "ptnr1_symmetry", 
-			"ptnr2_label_asym_id", "ptnr2_label_seq_id", "ptnr2_auth_seq_id", "ptnr2_label_atom_id", "ptnr2_symmetry", 
-			"pdbx_dist_value"
-		))
+	for (const auto &[asym1, seqid1, authseqid1, atomid1, symm1,
+			 asym2, seqid2, authseqid2, atomid2, symm2,
+			 dist] : struct_conn.find<std::string, std::optional<int>, std::string, std::string, std::string,
+			 std::string, std::optional<int>, std::string, std::string, std::string,
+			 float>(
+			 cif::key("ptnr1_symmetry") != "1_555" or cif::key("ptnr2_symmetry") != "1_555",
+			 "ptnr1_label_asym_id", "ptnr1_label_seq_id", "ptnr1_auth_seq_id", "ptnr1_label_atom_id", "ptnr1_symmetry",
+			 "ptnr2_label_asym_id", "ptnr2_label_seq_id", "ptnr2_auth_seq_id", "ptnr2_label_atom_id", "ptnr2_symmetry",
+			 "pdbx_dist_value"))
 	{
-		cif::point p1 = atom_site.find1<float,float,float>(
+		cif::point p1 = atom_site.find1<float, float, float>(
 			"label_asym_id"_key == asym1 and "label_seq_id"_key == seqid1 and "auth_seq_id"_key == authseqid1 and "label_atom_id"_key == atomid1,
 			"cartn_x", "cartn_y", "cartn_z");
-		cif::point p2 = atom_site.find1<float,float,float>(
+		cif::point p2 = atom_site.find1<float, float, float>(
 			"label_asym_id"_key == asym2 and "label_seq_id"_key == seqid2 and "auth_seq_id"_key == authseqid2 and "label_atom_id"_key == atomid2,
 			"cartn_x", "cartn_y", "cartn_z");
 
 		auto sa1 = c.symmetry_copy(p1, cif::sym_op(symm1));
 		auto sa2 = c.symmetry_copy(p2, cif::sym_op(symm2));
 
-		REQUIRE_THAT(cif::distance(sa1, sa2), Catch::Matchers::WithinAbs(dist, 0.5f));
+		CHECK_THAT(cif::distance(sa1, sa2), Catch::Matchers::WithinAbs(dist, 0.5f));
 
 		const auto &[d, p, so] = c.closest_symmetry_copy(p1, p2);
 
-		REQUIRE_THAT(p.m_x, Catch::Matchers::WithinAbs(sa2.m_x, 0.5f));
-		REQUIRE_THAT(p.m_y, Catch::Matchers::WithinAbs(sa2.m_y, 0.5f));
-		REQUIRE_THAT(p.m_z, Catch::Matchers::WithinAbs(sa2.m_z, 0.5f));
+		CHECK_THAT(p.m_x, Catch::Matchers::WithinAbs(sa2.m_x, 0.5f));
+		CHECK_THAT(p.m_y, Catch::Matchers::WithinAbs(sa2.m_y, 0.5f));
+		CHECK_THAT(p.m_z, Catch::Matchers::WithinAbs(sa2.m_z, 0.5f));
 
-		REQUIRE_THAT(d, Catch::Matchers::WithinAbs(dist, 0.5f));
+		CHECK_THAT(d, Catch::Matchers::WithinAbs(dist, 0.5f));
 		REQUIRE(so.string() == symm2);
 	}
 }
 
-TEST_CASE("symm_3bwh_1, *utf::tolerance(0.1f)")
+TEST_CASE("symm_3bwh_1")
 {
 	cif::file f(gTestDir / "3bwh.cif.gz");
 
@@ -555,15 +587,15 @@ TEST_CASE("symm_3bwh_1, *utf::tolerance(0.1f)")
 		{
 			if (a1 == a2)
 				continue;
-			
-			const auto&[ d, p, so ] = c.closest_symmetry_copy(a1.get_location(), a2.get_location());
 
-			REQUIRE_THAT(d, Catch::Matchers::WithinAbs(distance(a1.get_location(), p), 0.5f));
+			const auto &[d, p, so] = c.closest_symmetry_copy(a1.get_location(), a2.get_location());
+
+			CHECK_THAT(d, Catch::Matchers::WithinAbs(distance(a1.get_location(), p), 0.5f));
 		}
 	}
 }
 
-TEST_CASE("volume_3bwh_1, *utf::tolerance(0.1f)")
+TEST_CASE("volume_3bwh_1")
 {
 	cif::file f(gTestDir / "1juh.cif.gz");
 
@@ -571,6 +603,5 @@ TEST_CASE("volume_3bwh_1, *utf::tolerance(0.1f)")
 
 	cif::crystal c(db);
 
-	REQUIRE_THAT(c.get_cell().get_volume(), Catch::Matchers::WithinRel(741009.625f, 0.01f));
+	CHECK_THAT(c.get_cell().get_volume(), Catch::Matchers::WithinRel(741009.625f, 0.01f));
 }
-
