@@ -28,8 +28,6 @@
 
 #include <cif++.hpp>
 
-#include "cif++/dictionary_parser.hpp"
-
 #include <stdexcept>
 
 // --------------------------------------------------------------------
@@ -50,6 +48,23 @@ cif::file operator""_cf(const char *text, std::size_t length)
 
 // --------------------------------------------------------------------
 
+TEST_CASE("text_1")
+{
+	CHECK(cif::iequals("TEST", "test"));
+	CHECK(cif::iequals(std::string_view{"TEST"}, std::string_view{"test"}));
+
+	CHECK(cif::icompare("TEST", "test") == 0);
+	CHECK(cif::icompare(std::string_view{"TEST"}, std::string_view{"test"}) == 0);
+
+	CHECK(cif::icompare("TEST1", "test") > 0);
+	CHECK(cif::icompare(std::string_view{"TEST1"}, std::string_view{"test"}) > 0);
+
+	CHECK(cif::icompare("aap", "noot") < 0);
+	CHECK(cif::icompare(std::string_view{"aap"}, std::string_view{"noot"}) < 0);
+}
+
+// --------------------------------------------------------------------
+
 TEST_CASE("from_chars_1")
 {
 auto f = R"(data_TEST
@@ -70,8 +85,6 @@ _test.v
 	auto r2 = c.back();
 	REQUIRE(r2.get<double>("v") == 616.487);
 	REQUIRE(r2["v"].compare(616.487) == 0);
-
-
 }
 
 // --------------------------------------------------------------------
@@ -756,10 +769,9 @@ save__cat_2.desc
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -790,7 +802,7 @@ _cat_2.desc
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	SECTION("one")
 	{
@@ -909,10 +921,9 @@ save__cat_1.c
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -935,7 +946,7 @@ mies Mies
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 
@@ -1071,10 +1082,9 @@ save__cat_2.desc
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -1108,7 +1118,7 @@ _cat_2.desc
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -1274,10 +1284,9 @@ save__cat_2.parent_id3
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -1321,7 +1330,7 @@ _cat_2.parent_id3
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -1495,10 +1504,9 @@ cat_2 3 cat_2:cat_1:3
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -1535,7 +1543,7 @@ _cat_2.parent_id3
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -1735,10 +1743,9 @@ cat_2 1 cat_2:cat_1:1
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -1775,7 +1782,7 @@ _cat_2.parent_id_2
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	// auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -2131,10 +2138,9 @@ cat_2 1 '_cat_2.num'  '_cat_3.num'  cat_3
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -2176,7 +2182,7 @@ _cat_3.num
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -2416,10 +2422,9 @@ cat_2 1 '_cat_2.num'  '_cat_3.num'  cat_3
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -2461,7 +2466,7 @@ _cat_3.num
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 	auto &cat2 = f.front()["cat_2"];
@@ -3013,10 +3018,9 @@ save__cat_1.name
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -3039,7 +3043,7 @@ _cat_1.name
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	REQUIRE(f.is_valid());
 
@@ -3208,10 +3212,9 @@ save__cat_1.name
 
 	std::istream is_dict(&buffer);
 
-	auto &validator = cif::validator_factory::instance().construct_validator("test_dict.dic", is_dict);
+	auto &validator = cif::validator_factory::instance().add(cif::validator(is_dict));
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -3238,19 +3241,21 @@ _cat_1.name
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
-	REQUIRE(f.is_valid());
+	CHECK(f.is_valid());
 
 	std::stringstream ss;
 	ss << f;
 
 	cif::file f2(ss);
-	REQUIRE(f2.is_valid());
+	REQUIRE(f2.empty() == false);
+	f2.front().load_dictionary();
+	CHECK(f2.is_valid());
 
 	auto &audit_conform = f2.front()["audit_conform"];
-	REQUIRE(audit_conform.front()["dict_name"].as<std::string>() == "test_dict.dic");
-	REQUIRE(audit_conform.front()["dict_version"].as<float>() == 1.0);
+	CHECK(audit_conform.front()["dict_name"].as<std::string>() == "test_dict.dic");
+	CHECK(audit_conform.front()["dict_version"].as<float>() == 1.0);
 }
 
 // --------------------------------------------------------------------
@@ -3315,10 +3320,9 @@ save__cat_1.id_2
 
 	std::istream is_dict(&buffer);
 
-	auto validator = cif::parse_dictionary("test", is_dict);
+	cif::validator validator(is_dict);
 
 	cif::file f;
-	f.set_validator(&validator);
 
 	// --------------------------------------------------------------------
 
@@ -3343,7 +3347,7 @@ _cat_1.id_2
 	} data_buffer(const_cast<char *>(data), sizeof(data) - 1);
 
 	std::istream is_data(&data_buffer);
-	f.load(is_data);
+	f.load(is_data, validator);
 
 	auto &cat1 = f.front()["cat_1"];
 
@@ -3563,4 +3567,4 @@ TEST_CASE("pdb2cif_formula_weight")
 TEST_CASE("update_values_with_provider")
 {
 
-}
\ No newline at end of file
+}
